@@ -1,6 +1,6 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU Lesser General Public License (See COPYING for details).
-// Copyright (C) 2005 - 2007 Simon Goodall
+// Copyright (C) 2005 - 2008 Simon Goodall
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -19,12 +19,13 @@
 namespace WFUT {
 
 static const bool debug = false;
+
 // Create the parent dir of the file.
 // TODO Does this work if the parent parent dir does not exist?
 static int createParentDirs(const std::string &filename) {
   int err = 1;
   // TODO This function may not work correctly or be portable.
-  // Perhaps should only search for \\ on win32, / otherwise
+  // Perhaps should only search for '\\' on win32, '/' otherwise
   size_t pos = filename.find_last_of("\\/");
   // Return if no separator is found, or if it is the first
   // character, e.g. /home
@@ -36,6 +37,7 @@ static int createParentDirs(const std::string &filename) {
     // There was an error creating the parent path.
     return err;
   }
+
   // See if the directory already exists
   DIR *d = opendir(path.c_str());
   if (!d) {
@@ -81,6 +83,8 @@ static int copy_file(FILE *fp, const std::string &target_filename) {
 static size_t write_data(void *buffer, size_t size, size_t nmemb,void *userp) {
   assert(userp != NULL);
   DataStruct *ds = reinterpret_cast<DataStruct*>(userp);
+  
+  // Need to create a file in fp is NULL
   if (ds->fp == NULL) {
     // Open File handle
     ds->fp = os_create_tmpfile();
@@ -94,12 +98,17 @@ static size_t write_data(void *buffer, size_t size, size_t nmemb,void *userp) {
   }
 
   assert(ds->fp != NULL);
+
   // Update crc32 value
   ds->actual_crc32 = crc32(ds->actual_crc32, reinterpret_cast<Bytef*>(buffer), size * nmemb);
+
   // Write data to file
   return fwrite(buffer, size, nmemb, ds->fp);
 }
 
+/**
+ * Set some options that each handle needs
+ */
 static int setDefaultOpts(CURL *handle) {
   curl_easy_setopt(handle, CURLOPT_FOLLOWLOCATION, 1);
   curl_easy_setopt(handle, CURLOPT_WRITEFUNCTION, write_data);
@@ -107,7 +116,6 @@ static int setDefaultOpts(CURL *handle) {
   return 0;
 }
 
-
 int IO::init() {
   assert (m_initialised == false);
 
@@ -217,6 +225,7 @@ int IO::queueFile(const std::string &path, const std::string &filename, const st
     // Url already in queue
     return 1;
   }
+
   DataStruct *ds = new DataStruct();
   ds->fp = NULL;
   ds->url = Encoder::encodeURL(url);
@@ -235,19 +244,20 @@ int IO::queueFile(const std::string &path, const std::string &filename, const st
 
   // Add handle to our queue instead of to curl directly so that
   // we can limit the number of connections we make to the server.
-  m_handles.push(ds->handle);
-//  curl_multi_add_handle(m_mhandle, ds->handle);
+  m_handles.push_back(ds->handle);
 
   return 0;
 }
 
 int IO::poll() {
+  // Do some work and get number of handles in progress
   int num_handles;
   curl_multi_perform(m_mhandle, &num_handles);
 
   struct CURLMsg *msg = NULL;
   int msgs;
 
+  // Get messages back out of CURL
   while ((msg = curl_multi_info_read(m_mhandle, &msgs)) != NULL) {
 
     DataStruct *ds = NULL;
@@ -273,6 +283,8 @@ int IO::poll() {
               errormsg = "Error copying file to target location.\n";
               failed = true;
             }
+
+            // Set executable if required
             if (ds->executable) {
               os_set_executable(ds->path + "/" + ds->filename);
             }
@@ -296,9 +308,11 @@ int IO::poll() {
     }
 
     if (debug) printf("Removing Handle\n");
+
     // Close handle	
     curl_multi_remove_handle(m_mhandle, msg->easy_handle);
 
+    // Clean up
     if (ds) {
       if (ds->fp) os_free_tmpfile(ds->fp);
       ds->fp = NULL;
@@ -319,10 +333,11 @@ int IO::poll() {
   int diff = m_num_to_process - num_handles;
   if (diff > 0) {
     while (diff--) {
+
       if (!m_handles.empty()) {
         // This is where we tell curl about our downloads.
         curl_multi_add_handle(m_mhandle, m_handles.front());
-        m_handles.pop();
+        m_handles.pop_front();
         ++num_handles;
       }
     }
@@ -331,4 +346,58 @@ int IO::poll() {
   return num_handles;
 }
 
+/**
+ * Abort all current and pending downloads.
+ */
+void IO::abortAll() {
+
+  while (!m_files.empty()) {
+    DataStruct *ds = (m_files.begin())->second;
+    abortDownload(ds);
+    delete ds;
+    m_files.erase(m_files.begin());
+  }
+}
+
+/**
+ * Abort all current and pending downloads.
+ */
+void IO::abortDownload(const std::string &filename) {
+  std::map<std::string, DataStruct*>::iterator I = m_files.find(filename);
+
+  if (I != m_files.end()) {
+    DataStruct *ds = I->second;
+    abortDownload(ds);
+    delete ds;
+    m_files.erase(I);
+  }
+}
+
+void IO::abortDownload(DataStruct *ds) {
+
+  if (ds->handle) {
+    // Find handle in pending list
+    std::deque<CURL*>::iterator I = std::find(m_handles.begin(), m_handles.end(), ds->handle);
+    // Not found? Must be currently downloading.
+    if (I != m_handles.end()) {
+      m_handles.erase(I);
+    } else {
+      curl_multi_remove_handle(m_mhandle, ds->handle);
+    }
+
+    // Clean up curl handle
+    curl_easy_cleanup(ds->handle);
+    ds->handle = NULL;
+  }
+
+  // Clean up file pointer
+  if (ds->fp) {
+    os_free_tmpfile(ds->fp);
+    ds->fp = NULL;
+  }
+
+  // Trigger user feedback
+  DownloadFailed.emit(ds->url, ds->filename, "Aborted");
+}
+
 } /* namespace WFUT */
