@@ -1,6 +1,6 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU Lesser General Public License (See COPYING for details).
-// Copyright (C) 2005 - 2007 Simon Goodall
+// Copyright (C) 2005 - 2008 Simon Goodall
 
 #ifndef LIBWFUT_IO_H
 #define LIBWFUT_IO_H 1
@@ -8,7 +8,7 @@
 #include <cassert>
 #include <string>
 #include <map>
-#include <queue>
+#include <deque>
 #include <cstdio>
 
 #include <zlib.h>
@@ -18,6 +18,7 @@
 #include <libwfut/types.h>
 
 namespace WFUT {
+  // Internal data struct representing a single file being downloaded.
   typedef struct {
     std::string filename;
     std::string path;
@@ -112,11 +113,24 @@ public:
    */ 
   void setMaxDownloads(int i) { m_num_to_process = i; }
 
+  /**
+   * Abort all current and pending downloads.
+   */ 
+  void abortAll();
+
+  /**
+   * Abort the download of the specified file.
+   */ 
+  void abortDownload(const std::string &);
+
 private:
+
+  void abortDownload(DataStruct *ds);
+
   bool m_initialised;
   CURLM *m_mhandle;
   std::map<std::string, DataStruct*> m_files;
-  std::queue<CURL*> m_handles;
+  std::deque<CURL*> m_handles;
   int m_num_to_process;
 };
 
