@@ -165,6 +165,16 @@ public:
    */
   sigc::signal<void, const std::string&, const WFUTUpdateReason> UpdateReason;
 
+  /** Abort all current and pending downloads.
+   * The DownloadFailed signal will be fired with an "Aborted" message. 
+   */
+  void abortAll();
+
+  /** Abort specified current or pending downloa .
+   * The DownloadFailed signal will be fired with an "Aborted" message. 
+   */
+  void abortDownload(const std::string &filename);
+
 private:
   void onDownloadComplete(const std::string &url, const std::string &filename);
   void onDownloadFailed(const std::string &url, const std::string &filename, const std::string &reason);
